==> react-atom-progress-bar-2.12.0.tgz: package/lib/ProgressBarCircle/Circle/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { useEffect, useState } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import { MAX_TRANSITION_TIME_IN_MS, MODIFIERS, SIZES } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Circle = function Circle(_ref) {
  var _cx, _cx2, _cx3;
  var baseClassName = _ref.baseClassName,
    modifier = _ref.modifier,
    percentage = _ref.percentage,
    size = _ref.size,
    withAnimation = _ref.withAnimation,
    mainStrokeWidth = _ref.mainStrokeWidth,
    progressStrokeWidth = _ref.progressStrokeWidth,
    strokeLineCap = _ref.strokeLineCap;
  var _useState = useState(percentage),
    currentPercentage = _useState[0],
    setCurrentPercentage = _useState[1];
  var _useState2 = useState(0),
    transitionTime = _useState2[0],
    setTransitionTime = _useState2[1];
  useEffect(function (currentPercentage, percentage) {
    if (Math.abs(percentage - currentPercentage) < 5) {
      setCurrentPercentage(percentage);
      setTransitionTime(0);
    } else {
      setCurrentPercentage(percentage);
      setTransitionTime(MAX_TRANSITION_TIME_IN_MS * percentage / 100 / 1000);
    }
  }, [currentPercentage, percentage]);
  var getRadius = function getRadius() {
    return mainStrokeWidth === progressStrokeWidth ? 50 - mainStrokeWidth / 2 : 50 - Math.max.apply(Math, [progressStrokeWidth, mainStrokeWidth]) / 2;
  };
  var getPathStyles = function getPathStyles(_ref2) {
    var percentage = _ref2.percentage,
      strokeWidth = _ref2.strokeWidth;
    var radius = getRadius();
    var d = "M 50,50 m 0,-" + radius + "\n     a " + radius + "," + radius + " 0 1 1 0," + 2 * radius + "\n     a " + radius + "," + radius + " 0 1 1 0,-" + 2 * radius;
    var len = Math.PI * 2 * radius;
    var style = {
      strokeDasharray: len + "px " + len + "px",
      strokeDashoffset: (100 - percentage) / 100 * len + "px",
      transition: withAnimation ? "stroke-dashoffset " + transitionTime + "s ease 0s, stroke " + transitionTime + "s ease" : ''
    };
    return {
      d: d,
      style: style
    };
  };
  return /*#__PURE__*/_jsxs("svg", {
    className: cx(baseClassName + "-circle", (_cx = {}, _cx[baseClassName + "-circle--" + modifier] = !!modifier, _cx[baseClassName + "-circle--" + size] = !!size, _cx)),
    viewBox: "0 0 100 100",
    children: [/*#__PURE__*/_jsx("path", _extends({
      className: cx(baseClassName + "-trail", (_cx2 = {}, _cx2[baseClassName + "-trail--" + modifier] = !!modifier, _cx2))
    }, getPathStyles({
      percentage: 100,
      strokeWidth: mainStrokeWidth
    }), {
      strokeWidth: mainStrokeWidth,
      fillOpacity: "0"
    })), /*#__PURE__*/_jsx("path", _extends({
      className: cx(baseClassName + "-path", (_cx3 = {}, _cx3[baseClassName + "-path--" + modifier] = !!modifier, _cx3))
    }, getPathStyles({
      percentage: percentage,
      strokeWidth: progressStrokeWidth
    }), {
      strokeLinecap: strokeLineCap,
      strokeWidth: progressStrokeWidth,
      fillOpacity: "0"
    }))]
  });
};
Circle.defaultProps = {
  withAnimation: true
};
export default Circle;

==> react-atom-progress-bar-2.14.0.tgz: package/lib/ProgressBarCircle/Circle/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { useEffect, useState } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import { MAX_TRANSITION_TIME_IN_MS, MODIFIERS, SIZES } from './settings.js';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
var Circle = function Circle(_ref) {
  var _cx, _cx2, _cx3;
  var baseClassName = _ref.baseClassName,
    modifier = _ref.modifier,
    percentage = _ref.percentage,
    size = _ref.size,
    _ref$withAnimation = _ref.withAnimation,
    withAnimation = _ref$withAnimation === void 0 ? true : _ref$withAnimation,
    mainStrokeWidth = _ref.mainStrokeWidth,
    progressStrokeWidth = _ref.progressStrokeWidth,
    strokeLineCap = _ref.strokeLineCap;
  var _useState = useState(percentage),
    currentPercentage = _useState[0],
    setCurrentPercentage = _useState[1];
  var _useState2 = useState(0),
    transitionTime = _useState2[0],
    setTransitionTime = _useState2[1];
  useEffect(function (currentPercentage, percentage) {
    if (Math.abs(percentage - currentPercentage) < 5) {
      setCurrentPercentage(percentage);
      setTransitionTime(0);
    } else {
      setCurrentPercentage(percentage);
      setTransitionTime(MAX_TRANSITION_TIME_IN_MS * percentage / 100 / 1000);
    }
  }, [currentPercentage, percentage]);
  var getRadius = function getRadius() {
    return mainStrokeWidth === progressStrokeWidth ? 50 - mainStrokeWidth / 2 : 50 - Math.max.apply(Math, [progressStrokeWidth, mainStrokeWidth]) / 2;
  };
  var getPathStyles = function getPathStyles(_ref2) {
    var percentage = _ref2.percentage,
      strokeWidth = _ref2.strokeWidth;
    var radius = getRadius();
    var d = "M 50,50 m 0,-" + radius + "\n     a " + radius + "," + radius + " 0 1 1 0," + 2 * radius + "\n     a " + radius + "," + radius + " 0 1 1 0,-" + 2 * radius;
    var len = Math.PI * 2 * radius;
    var style = {
      strokeDasharray: len + "px " + len + "px",
      strokeDashoffset: (100 - percentage) / 100 * len + "px",
      transition: withAnimation ? "stroke-dashoffset " + transitionTime + "s ease 0s, stroke " + transitionTime + "s ease" : ''
    };
    return {
      d: d,
      style: style
    };
  };
  return /*#__PURE__*/_jsxs("svg", {
    className: cx(baseClassName + "-circle", (_cx = {}, _cx[baseClassName + "-circle--" + modifier] = !!modifier, _cx[baseClassName + "-circle--" + size] = !!size, _cx)),
    viewBox: "0 0 100 100",
    children: [/*#__PURE__*/_jsx("path", _extends({
      className: cx(baseClassName + "-trail", (_cx2 = {}, _cx2[baseClassName + "-trail--" + modifier] = !!modifier, _cx2))
    }, getPathStyles({
      percentage: 100,
      strokeWidth: mainStrokeWidth
    }), {
      strokeWidth: mainStrokeWidth,
      fillOpacity: "0"
    })), /*#__PURE__*/_jsx("path", _extends({
      className: cx(baseClassName + "-path", (_cx3 = {}, _cx3[baseClassName + "-path--" + modifier] = !!modifier, _cx3))
    }, getPathStyles({
      percentage: percentage,
      strokeWidth: progressStrokeWidth
    }), {
      strokeLinecap: strokeLineCap,
      strokeWidth: progressStrokeWidth,
      fillOpacity: "0"
    }))]
  });
};
export default Circle;
